Name:		autokey
Version:	0.95.2
Release:	1%{?dist}
Summary:	Desktop automation utility 


Group:		Applications/Productivity
License:	GPLv3
URL:		https://github.com/autokey/autokey
Source0:	https://github.com/autokey/autokey/archive/v%{version}.tar.gz


BuildArch:	noarch 
BuildRequires:	python3-devel,python3-xlib,python3-inotify,python3-dbus,python3-setuptools,python3-qt5-devel,python3-qscintilla


%description
AutoKey is a desktop automation utility for Linux and X11. It allows 
the automation of virtually any task by responding to typed abbreviations 
and hot keys. It offers a full-featured GUI that makes it highly 
accessible for novices, as well as a scripting interface offering 
the full flexibility and power of the Python language.

%package common
Summary:	Desktop automation utility - common data	
Group:		Applications/Productivity
Requires:	python3-dbus
Requires:	%{py3_dist pyinotify}
Requires:	%{py3_dist python-xlib}
Requires:	wmctrl
Provides:	autokey = %{version}-%{release}


%description common
This package contains the common data shared between the various front ends.


%package gtk
Summary:	AutoKey GTK+ front end
Group:		Applications/Productivity
Requires:	libappindicator-gtk3
Requires:	pygtksourceview
Requires:	python3-gobject
Requires:	zenity
Requires:	autokey-common = %{version}-%{release}
Provides:	autokey = %{version}-%{release}
%description gtk
This package contains the GTK+ front end for autokey


%package qt
Summary:	AutoKey QT front end
Group:		Applications/Productivity
Requires:	python3-qscintilla
Requires:	autokey-common = %{version}-%{release}
%{?_qt5_version:Requires: qt5 >= %{_qt5_version}}
Provides:	autokey = %{version}-%{release}
%description qt
This package contains the QT front end for autokey


%prep
%setup -q -n %{name}-%{version}


%build
%{__python3} setup.py build


%install
rm -rf %{buildroot}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot} --prefix %{_prefix}

# remove shebang from python libraries
for lib in $(find %{buildroot}%{python3_sitelib}/autokey/ -name "*.py"); do
 sed '/\/usr\/bin\/env/d' $lib > $lib.new &&
 touch -r $lib $lib.new &&
 mv $lib.new $lib
done

# ensure pkg_resources is able to find the required python packages
sed -i 's/dbus-python/pydbus/' %{buildroot}%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info/requires.txt
sed -i 's/python3-xlib/python-xlib/' %{buildroot}%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info/requires.txt

%files common
%defattr(-,root,root)
%doc ACKNOWLEDGMENTS README.rst new_features.rst CHANGELOG.rst
%{python3_sitelib}/*
%exclude %{python3_sitelib}/autokey/gtkapp.py*
%exclude %{python3_sitelib}/autokey/gtkui/*
%exclude %{python3_sitelib}/autokey/qtapp.py*
%exclude %{python3_sitelib}/autokey/qtui/*
%{_datadir}/icons/*
%{_bindir}/autokey-run
%{_bindir}/autokey-shell
%{_mandir}/man1/autokey-run.1*

%files gtk
%defattr(-,root,root)
%{_bindir}/autokey-gtk
%{python3_sitelib}/autokey/gtkapp.py*
%{python3_sitelib}/autokey/gtkui/*
%{_datadir}/applications/autokey-gtk.desktop
%{_mandir}/man1/autokey-gtk.1*

%files qt
%defattr(-,root,root)
%{_bindir}/autokey-qt
%{python3_sitelib}/autokey/qtapp.py*
%{python3_sitelib}/autokey/qtui/*
%{_datadir}/applications/autokey-qt.desktop
%{_mandir}/man1/autokey-qt.1*


%changelog
* Sun Jul 23 2018 Raghu Udiyar <raghusiddarth@gmail.com> - 0.95.2-1
- Update to latest 0.95.2 release (#1596426)

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.94.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 0.94.0-2
- Rebuilt for Python 3.7

* Tue May 01 2018 Raghu Udiyar <raghusiddarth@gmail.com> - 0.94.0-1
- Update to latest 0.94.0 and use python3 (#1567688)

* Wed Apr 04 2018 Kalev Lember <klember@redhat.com> - 0.90.4-14
- Add missing dependencies for autokey-gtk (#1520592)

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.90.4-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Jan 07 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.90.4-12
- Remove obsolete scriptlets

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.90.4-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.90.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.90.4-9
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.90.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.90.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.90.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild


* Mon Sep 16 2013 Raghu Udiyar <raghusiddarth@gmail.com> - 0.90.4-5
- Updated pygtksourceview dependency to gtksourceview3

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.90.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.90.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.90.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 17 2012 Raghu Udiyar <raghusiddarth@gmail.com> 0.90.4-1
- Update to upstream 0.90-4 release
- Qt interface is back with major updates to both frontends
- Back to the old split package structure

* Tue Jan 10 2012 Matěj Cepl <mcepl@redhat.com> 0.81.4-1
- Upgrade to the latest upstream package.

* Tue Nov 22 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.81.0-2
- Add autokey-run files to the package

* Tue Nov 22 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.81.0-1
- Update to upstream 0.81.0 release
- Changelog : http://code.google.com/p/autokey/source/browse/trunk/debian/changelog?r=408

* Wed Oct 26 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.80.3-1
- Update to upstream 0.80.3 release
- Changelog : http://code.google.com/p/autokey/source/browse/trunk/debian/changelog?spec=svn379&r=379

* Sat Oct 8 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.80.2-1
- Update to upstream 0.80.2 release
- Qt interface deprecated and removed
- Change package structure and remove qt subpackage/files
- Updated application icon
- Full changelog : http://code.google.com/p/autokey/source/browse/trunk/debian/changelog?spec=svn376&r=376

* Thu Jul 21 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.3-4
- Update to upstream 0.71.3-2 release
- Source tarball now extracts to "autokey-version" instead of "build" directory
- The README file now explicitly mentions the licence
- Drop defattr from the spec since recent RPM makes it redundant

* Fri Jul 15 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.3-3
- Add build requirement for desktop-file-utils
- Require pygtksourceview for gtk frontend
- Require qscintilla-python for qt frontend

* Wed May 25 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.3-2
- Improve spec readability

* Tue Apr 19 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.3-1
- Update to upstream 0.71.3 release

* Sun Mar 13 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.2-6
- Add desktop-file-validate

* Sun Mar 06 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.2-5
- Remove Python-xlib dependency
- Add doc/scripting to docs

* Fri Mar 04 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.2-4
- Remove deprecated daemon, see : http://code.google.com/p/autokey/issues/detail?id=106

* Mon Feb 28 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.2-3
- Add script to remove shebang from python libraries
- Remove default start from initscript
- Add patch to use lockfile in initscript

* Wed Feb 02 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.2-2
- Add postun scriptlet to handle upgrades
- Set autokey service to start only in runlevel 5

* Sun Jan 30 2011 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.2-1
- Update to upstream 0.71.2 release
- Add COPYING file to docs
- Update init script to match upstream

* Sat Dec 18 2010 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.1-1
- Update to upstream 0.71.1 release

* Fri Oct 01 2010 Raghu Udiyar <raghusiddarth@gmail.com> 0.71.0-1
- Initial version of the package
